@@ -1,5 +1,4 @@
-/* Copyright (c) 2012-2014, 2016. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2012-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -16,13 +15,13 @@ public class Node extends Process {
   public Node(Host host, String name, String[]args) {
    super(host,name,args);
   }
-  public void request(double CStime) throws MsgException {
+  public void request(double csTime) throws MsgException {
     RequestTask req = new RequestTask(getName());
     Msg.info("Send a request to the coordinator");
     req.send("coordinator");
     Msg.info("Wait for a grant from the coordinator");
     GrantTask.receive(getName());
-    Task compute = new Task("CS", CStime, 0);
+    Task compute = new Task("CS", csTime, 0);
     compute.execute();
     ReleaseTask release = new ReleaseTask();
     release.send("coordinator");
