@@ -1,5 +1,4 @@
-/* Copyright (c) 2012-2014, 2016. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2012-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -8,7 +7,7 @@ package app.centralizedmutex;
 import org.simgrid.msg.Task;
 
 public class RequestTask extends Task {
-  String from;
+  protected String from;
   public RequestTask(String name) {
     super();
     from=name;
