@@ -1,11 +1,10 @@
-/* Copyright (c) 2016. The SimGrid Team. All rights reserved.               */
+/* Copyright (c) 2016-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 package app.tokenring;
 import org.simgrid.msg.Host;
-import org.simgrid.msg.HostNotFoundException;
 import org.simgrid.msg.Msg;
 import org.simgrid.msg.Process;
 
@@ -15,7 +14,7 @@ class Main {
 		throw new IllegalAccessError("Utility class");
 	}
 
-	public static void main(String[] args) throws HostNotFoundException {
+	public static void main(String[] args) {
 		Msg.init(args);
 		
 		String platform = "../platforms/small_platform.xml";
