@@ -6,12 +6,10 @@
 
 package async.dsend;
 import org.simgrid.msg.Msg;
-import org.simgrid.msg.Comm;
 import org.simgrid.msg.Host;
 import org.simgrid.msg.Task;
 import org.simgrid.msg.Process;
 import org.simgrid.msg.HostFailureException;
-import org.simgrid.msg.TaskCancelledException;
 import org.simgrid.msg.TimeoutException;
 import org.simgrid.msg.TransferFailureException;
 
@@ -20,6 +18,7 @@ public class Receiver extends Process {
     super(host,name);
   }
 
+  @Override
   public void main(String[] args) throws TransferFailureException, HostFailureException, TimeoutException {
     Msg.info("Receiving on '"+ getHost().getName() + "'");
     Task.receive(getHost().getName());
