@@ -5,10 +5,8 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 package async.dsend;
-import java.util.ArrayList;
 
 import org.simgrid.msg.Msg;
-import org.simgrid.msg.Comm;
 import org.simgrid.msg.Host;
 import org.simgrid.msg.Task;
 import org.simgrid.msg.Process;
@@ -19,6 +17,7 @@ public class Sender extends Process {
     super(host,name);
   }
 
+  @Override
   public void main(String[] args) throws MsgException {
     double taskComputeSize =0;
     double taskCommunicateSize = 5000000;
@@ -34,10 +33,10 @@ public class Sender extends Process {
     }
 
     Msg.info("All tasks have been (asynchronously) dispatched."+
-             " Let's sleep for 10s so that nobody gets a message from a terminated process.");
+             " Let's sleep for 20s so that nobody gets a message from a terminated process.");
 
-    waitFor(10);
+    waitFor(20);
 
-    Msg.info("Goodbye now!");
+    Msg.info("Done sleeping. Goodbye now!");
   }
 }
