@@ -22,6 +22,7 @@ class Main {
 
   public static void main(String[] args) {
     Msg.init(args); 
+    Msg.liveMigrationInit();
 
     String platfFile = "../../examples/platforms/small_platform.xml";
     if (args.length >= 1)
@@ -29,8 +30,8 @@ class Main {
     
     File f = new File(platfFile); 
     if (!f.exists()) {
-    	System.err.println("File "+platfFile+" does not exist in "+System.getProperty("user.dir"));
-    	System.err.println("Usage  : Main ../platforms/platform.xml");
+      Msg.error("File " + platfFile + " does not exist in " + System.getProperty("user.dir"));
+      Msg.error("Usage  : Main ../platforms/platform.xml");
     }
     
     Msg.createEnvironment(platfFile);
