@@ -7,10 +7,14 @@
 package dht.chord;
 
 public class FindSuccessorAnswerTask extends ChordTask {
-  public int answerId;
+  private int answerId;
 
   public FindSuccessorAnswerTask(String issuerHostname, String answerTo, int answerId) {
     super(issuerHostname,answerTo);
     this.answerId = answerId;
   }
+
+  public int getAnswerId(){
+    return this.answerId;
+  }
 }
