@@ -7,10 +7,14 @@
 package dht.chord;
 
 public class FindSuccessorTask extends ChordTask {
-  public int requestId;
+  private int requestId;
 
   public FindSuccessorTask(String issuerHostname, String answerTo,  int requestId) {
     super(issuerHostname, answerTo);
     this.requestId = requestId;
   }
+
+  public int getRequestId(){
+    return this.requestId;
+  }
 }
