@@ -7,9 +7,14 @@
 package dht.chord;
 
 public class GetPredecessorAnswerTask extends ChordTask {
-  public int answerId;
+  private int answerId;
+
   public GetPredecessorAnswerTask(String issuerHostname, String answerTo, int answerId) {
     super(issuerHostname,answerTo);
     this.answerId = answerId;
   }
+
+  public int getAnswerId(){
+    return this.answerId;
+  }
 }
