@@ -7,9 +7,14 @@
 package dht.chord;
 
 public class NotifyTask extends ChordTask {
-  public int requestId;
+  private int requestId;
+
   public NotifyTask(String issuerHostname, String answerTo, int requestId) {
     super(issuerHostname, answerTo);
     this.requestId = requestId;
   }
+
+  public int getRequestId(){
+    return this.requestId;
+  }
 }
