@@ -10,9 +10,6 @@ import org.simgrid.msg.Msg;
 import org.simgrid.msg.MsgException;
 
 public class Main {
-  public static final double task_comp_size = 10;
-  public static final double task_comm_size = 10;
-  public static final int hostNB = 2 ; 
   private Main() {
     throw new IllegalAccessError("Utility class");
   }
@@ -28,7 +25,7 @@ public class Main {
     }
     /* Construct the platform */
     Msg.createEnvironment(args[0]);
-    /* Instanciate a process */
+    /* Instantiate a process */
     new EnergyConsumer("MyHost1","energyConsumer").start();
     /* Execute the simulation */
     Msg.run();
