@@ -5,17 +5,16 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 package trace.pingpong;
-import org.simgrid.msg.NativeException;
 import org.simgrid.msg.Task;
 
 public class PingPongTask extends Task {
   private double timeVal;
 
-  public PingPongTask() throws NativeException {
+  public PingPongTask() {
     this.timeVal = 0;
   }
 
-  public PingPongTask(String name, double computeDuration, double messageSize) throws NativeException {
+  public PingPongTask(String name, double computeDuration, double messageSize) {
     super(name,computeDuration,messageSize);
   }
 
