@@ -1,5 +1,4 @@
-/* Copyright (c) 2010-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2010-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -28,7 +27,8 @@ static int server(int argc, char *argv[])
     MSG_task_receive(&task, "mymailbox");
     count++;
   }
-  MC_assert(xbt_str_parse_int(MSG_task_get_name(task), "Task names must be integers, not '%s'") == 3);
+  int value_got = xbt_str_parse_int(MSG_task_get_name(task), "Task names must be integers, not '%s'");
+  MC_assert(value_got == 3);
 
   XBT_INFO("OK");
   return 0;
