@@ -81,7 +81,7 @@ static int client(int argc, char *argv[])
 int main(int argc, char *argv[])
 {
   MSG_init(&argc, argv);
-  MSG_create_environment("../msg_platform.xml");
+  MSG_create_environment("../../platforms/small_platform.xml");
   MSG_function_register("coordinator", coordinator);
   MSG_function_register("client", client);
   MSG_launch_application("deploy_centralized_mutex.xml");
