@@ -30,8 +30,7 @@ int main(int argc, char **argv)
 
   SD_task_schedulel(task, 1, sg_host_by_name("Faulty Host"));
 
-  xbt_dynar_t tasks = SD_simulate(-1.0);
-  xbt_dynar_free(&tasks);
+  SD_simulate(-1.0);
 
   SD_task_dump(task);
 
@@ -43,8 +42,7 @@ int main(int argc, char **argv)
   SD_task_schedulel(task, 1, sg_host_by_name("Safe Host"));
 
   XBT_INFO("Run the simulation again");
-  tasks = SD_simulate(-1.0);
-  xbt_dynar_free(&tasks);
+  SD_simulate(-1.0);
 
   SD_task_dump(task);
   XBT_INFO("Task '%s' start time: %f, finish time: %f", SD_task_get_name(task), SD_task_get_start_time(task),
@@ -65,8 +63,7 @@ int main(int argc, char **argv)
   hosts[0] = sg_host_by_name("Faulty Host");
   SD_task_schedule(task, 1, hosts, computation_amount, communication_amount,-1);
 
-  tasks = SD_simulate(-1.0);
-  xbt_dynar_free(&tasks);
+  SD_simulate(-1.0);
 
   SD_task_dump(task);
 
@@ -81,14 +78,12 @@ int main(int argc, char **argv)
   SD_task_schedule(task, 1, hosts, computation_amount, communication_amount,-1);
 
   XBT_INFO("Run the simulation again");
-  tasks = SD_simulate(-1.0);
-  xbt_dynar_free(&tasks);
+  SD_simulate(-1.0);
 
   SD_task_dump(task);
   XBT_INFO("Task '%s' start time: %f, finish time: %f", SD_task_get_name(task), SD_task_get_start_time(task),
            SD_task_get_finish_time(task));
 
   SD_task_destroy(task);
-  SD_exit();
   return 0;
 }
