@@ -27,7 +27,6 @@ int main(int argc, char **argv){
   /* load the DOT file */
   dot = SD_PTG_dotload(argv[2]);
   if(dot == NULL){
-    SD_exit();
     xbt_die("No dot load may be you have a cycle in your graph");
   }
 
@@ -56,7 +55,5 @@ int main(int argc, char **argv){
   }
   xbt_dynar_free_container(&dot);
 
-  /* exit */
-  SD_exit();
   return 0;
 }
