@@ -12,11 +12,14 @@
 
 int main(int argc, char **argv)
 {
-  int x,y, err, size, rank;
+  int x;
+  int y;
+  int size;
+  int rank;
   MPI_Status status;
 
   /* Initialize MPI */
-  err = MPI_Init(&argc, &argv);
+  int err = MPI_Init(&argc, &argv);
   if (err != MPI_SUCCESS) {
     printf("MPI initialization failed!\n");
     exit(1);
