@@ -5,7 +5,9 @@
 int x = 20;
 
 int main(int argc, char **argv) {
-  int recv_x = 1, size, rank;
+  int recv_x = 1;
+  int size;
+  int rank;
   MPI_Status status;
 
   MPI_Init(&argc, &argv);
