@@ -37,9 +37,16 @@ namespace activity {
 
   class MailboxImpl;
 }
-
+namespace lmm {
+class Element;
+class Variable;
+class Constraint;
+class ConstraintLight;
+class System;
+}
 namespace routing {
   class NetPoint;
+  class NetZoneImpl;
 }
 }
 namespace simix {
@@ -56,7 +63,6 @@ namespace surf {
   class HostImpl;
   class StorageImpl;
   class StorageType;
-  class FileImpl;
 }
 namespace trace_mgr {
   class trace;
@@ -80,7 +86,14 @@ typedef simgrid::kernel::context::Context* smx_context_t;
 typedef simgrid::simix::ActorImpl* smx_actor_t;
 typedef simgrid::simix::MutexImpl* smx_mutex_t;
 typedef simgrid::kernel::activity::MailboxImpl* smx_mailbox_t;
-typedef simgrid::surf::FileImpl* surf_file_t;
+typedef simgrid::surf::StorageImpl* surf_storage_t;
+
+typedef simgrid::kernel::lmm::Element* lmm_element_t;
+typedef const simgrid::kernel::lmm::Element* const_lmm_element_t;
+typedef simgrid::kernel::lmm::Variable* lmm_variable_t;
+typedef simgrid::kernel::lmm::Constraint* lmm_constraint_t;
+typedef simgrid::kernel::lmm::ConstraintLight* lmm_constraint_light_t;
+typedef simgrid::kernel::lmm::System* lmm_system_t;
 
 #else
 
@@ -98,6 +111,9 @@ typedef struct Trace tmgr_Trace;
 
 typedef struct s_smx_context* smx_context_t;
 typedef struct s_smx_actor* smx_actor_t;
+typedef struct s_smx_mutex* smx_mutex_t;
+typedef struct s_smx_mailbox* smx_mailbox_t;
+typedef struct s_surf_storage* surf_storage_t;
 
 #endif
 
