@@ -14,9 +14,6 @@
 
 #if SIMGRID_HAVE_JEDULE
 
-XBT_ATTRIB_UNUSED static std::unordered_map <const char *, jed_container_t> host2_simgrid_parent_container;
-XBT_ATTRIB_UNUSED static std::unordered_map <std::string, jed_container_t> container_name2container;
-
 namespace simgrid {
 namespace jedule{
 
@@ -36,11 +33,9 @@ public:
 }
 }
 
-SG_BEGIN_DECL()
-
+extern "C" {
 typedef simgrid::jedule::Jedule *jedule_t;
-
-SG_END_DECL()
+}
 #endif
 
 #endif /* JEDULE_HPP_ */
