@@ -9,7 +9,7 @@
 #include <simgrid/s4u/forward.hpp>
 #include <simgrid/forward.h>
 
-typedef enum { inited = 0, started, canceled, errored, finished } e_s4u_activity_state_t;
+enum e_s4u_activity_state_t { inited = 0, started, canceled, errored, finished };
 
 namespace simgrid {
 namespace s4u {
@@ -20,8 +20,11 @@ namespace s4u {
  */
 XBT_PUBLIC_CLASS Activity {
   friend Comm;
-  friend void intrusive_ptr_release(Comm * c);
-  friend void intrusive_ptr_add_ref(Comm * c);
+  friend XBT_PUBLIC(void) intrusive_ptr_release(Comm * c);
+  friend XBT_PUBLIC(void) intrusive_ptr_add_ref(Comm * c);
+  friend Exec;
+  friend XBT_PUBLIC(void) intrusive_ptr_release(Exec * e);
+  friend XBT_PUBLIC(void) intrusive_ptr_add_ref(Exec * e);
 
 protected:
   Activity()  = default;
@@ -35,28 +38,32 @@ public:
    *
    * This function is optional: you can call wait() even if you didn't call start()
    */
-  virtual void start()=0;
+  virtual Activity* start() = 0;
   /** Tests whether the given activity is terminated yet. This is a pure function. */
   //virtual bool test()=0;
   /** Blocks until the activity is terminated */
-  virtual void wait()=0;
+  virtual Activity* wait() = 0;
   /** Blocks until the activity is terminated, or until the timeout is elapsed
    *  Raises: timeout exception.*/
-  virtual void wait(double timeout)=0;
+  virtual Activity* wait(double timeout) = 0;
   /** Cancel that activity */
   //virtual void cancel();
   /** Retrieve the current state of the activity */
   e_s4u_activity_state_t getState() {return state_;}
 
   /** Get the remaining amount of work that this Activity entails. When it's 0, it's done. */
-  double getRemains();
+  virtual double getRemains();
   /** Set the [remaining] amount of work that this Activity will entail
    *
    * It is forbidden to change the amount of work once the Activity is started */
-  void setRemains(double remains);
+  Activity* setRemains(double remains);
 
   /** Put some user data onto the Activity */
-  void setUserData(void *data) {userData_=data;}
+  Activity* setUserData(void* data)
+  {
+    userData_ = data;
+    return this;
+  }
   /** Retrieve the user data of the Activity */
   void *getUserData() { return userData_; }
 
