@@ -25,8 +25,8 @@ XBT_PUBLIC_CLASS Comm : public Activity
 {
   Comm() : Activity() {}
 public:
-  friend void intrusive_ptr_release(simgrid::s4u::Comm * c);
-  friend void intrusive_ptr_add_ref(simgrid::s4u::Comm * c);
+  friend XBT_PUBLIC(void) intrusive_ptr_release(simgrid::s4u::Comm* c);
+  friend XBT_PUBLIC(void) intrusive_ptr_add_ref(simgrid::s4u::Comm* c);
   friend Mailbox; // Factory of comms
 
   virtual ~Comm();
@@ -66,68 +66,68 @@ public:
   }
 
   /** Creates (but don't start) an async send to the mailbox @p dest */
-  static CommPtr XBT_ATTRIB_DEPRECATED_v320("Use Mailbox::put_init(): v3.20 will turn this warning into an error.")
-      send_init(MailboxPtr dest)
+  XBT_ATTRIB_DEPRECATED_v320("Use Mailbox::put_init(): v3.20 will turn this warning into an error.") static CommPtr
+  send_init(MailboxPtr dest)
   {
     return dest->put_init();
   }
   /** Creates (but don't start) an async send to the mailbox @p dest */
-  static CommPtr XBT_ATTRIB_DEPRECATED_v320("Use Mailbox::put_init(): v3.20 will turn this warning into an error.")
-      send_init(MailboxPtr dest, void* data, int simulatedByteAmount)
+  XBT_ATTRIB_DEPRECATED_v320("Use Mailbox::put_init(): v3.20 will turn this warning into an error.") static CommPtr
+  send_init(MailboxPtr dest, void* data, int simulatedByteAmount)
   {
     return dest->put_init(data, simulatedByteAmount);
   }
   /** Creates and start an async send to the mailbox @p dest */
-  static CommPtr XBT_ATTRIB_DEPRECATED_v320("Use Mailbox::put_async(): v3.20 will turn this warning into an error.")
-      send_async(MailboxPtr dest, void* data, int simulatedByteAmount)
+  XBT_ATTRIB_DEPRECATED_v320("Use Mailbox::put_async(): v3.20 will turn this warning into an error.") static CommPtr
+  send_async(MailboxPtr dest, void* data, int simulatedByteAmount)
   {
     return dest->put_async(data, simulatedByteAmount);
   }
   /** Creates (but don't start) an async recv onto the mailbox @p from */
-  static CommPtr XBT_ATTRIB_DEPRECATED_v320("Use Mailbox::get_init(): v3.20 will turn this warning into an error.")
-      recv_init(MailboxPtr from)
+  XBT_ATTRIB_DEPRECATED_v320("Use Mailbox::get_init(): v3.20 will turn this warning into an error.") static CommPtr
+  recv_init(MailboxPtr from)
   {
     return from->get_init();
   }
   /** Creates and start an async recv to the mailbox @p from */
-  static CommPtr XBT_ATTRIB_DEPRECATED_v320("Use Mailbox::get_async(): v3.20 will turn this warning into an error.")
-      recv_async(MailboxPtr from, void** data)
+  XBT_ATTRIB_DEPRECATED_v320("Use Mailbox::get_async(): v3.20 will turn this warning into an error.") static CommPtr
+  recv_async(MailboxPtr from, void** data)
   {
     return from->get_async(data);
   }
 
-  void start() override;
-  void wait() override;
-  void wait(double timeout) override;
+  Activity* start() override;
+  Activity* wait() override;
+  Activity* wait(double timeout) override;
 
   /** Start the comm, and ignore its result. It can be completely forgotten after that. */
-  void detach();
+  Activity* detach();
   /** Start the comm, and ignore its result. It can be completely forgotten after that. */
-  void detach(void (*cleanFunction)(void*))
+  Activity* detach(void (*cleanFunction)(void*))
   {
     cleanFunction_ = cleanFunction;
-    detach();
+    return detach();
   }
 
   /** Sets the maximal communication rate (in byte/sec). Must be done before start */
-  void setRate(double rate);
+  Activity* setRate(double rate);
 
   /** Specify the data to send */
-  void setSrcData(void* buff);
+  Activity* setSrcData(void* buff);
   /** Specify the size of the data to send */
-  void setSrcDataSize(size_t size);
+  Activity* setSrcDataSize(size_t size);
   /** Specify the data to send and its size */
-  void setSrcData(void* buff, size_t size);
+  Activity* setSrcData(void* buff, size_t size);
 
   /** Specify where to receive the data */
-  void setDstData(void** buff);
+  Activity* setDstData(void** buff);
   /** Specify the buffer in which the data should be received */
-  void setDstData(void** buff, size_t size);
+  Activity* setDstData(void** buff, size_t size);
   /** Retrieve the size of the received data */
   size_t getDstDataSize();
 
   bool test();
-  void cancel();
+  Activity* cancel();
 
   /** Retrieve the mailbox on which this comm acts */
   MailboxPtr getMailbox();
