@@ -1,4 +1,4 @@
-/* Copyright (c) 2016. The SimGrid Team.
+/* Copyright (c) 2016-2017. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -59,8 +59,8 @@ auto kernelSync(F code) -> decltype(code().get())
   simcall_run_blocking([&result, self, &code]{
     try {
       auto future = code();
-      future.then_([&result, self](simgrid::kernel::Future<T> value) {
-        simgrid::xbt::setPromise(result, value);
+      future.then_([&result, self](std::shared_ptr<simgrid::kernel::FutureState<T>>&& value) {
+        simgrid::xbt::setPromise(result, simgrid::kernel::Future<T>(value));
         simgrid::simix::unblock(self);
       });
     }
@@ -81,8 +81,8 @@ auto kernelSync(F code) -> decltype(code().get())
 template <class T>
 class Future {
 public:
-  Future() {}
-  Future(simgrid::kernel::Future<T> future) : future_(std::move(future)) {}
+  Future() { /* Nothing to do*/}
+  explicit Future(simgrid::kernel::Future<T> future) : future_(std::move(future)) {}
 
   bool valid() const { return future_.valid(); }
   T get()
@@ -94,9 +94,9 @@ public:
     simcall_run_blocking([this, &result, self]{
       try {
         // When the kernel future is ready...
-        this->future_.then_([&result, self](simgrid::kernel::Future<T> value) {
+        this->future_.then_([&result, self](std::shared_ptr<simgrid::kernel::FutureState<T>>&& value) {
           // ... wake up the process with the result of the kernel future.
-          simgrid::xbt::setPromise(result, value);
+          simgrid::xbt::setPromise(result, simgrid::kernel::Future<T>(value));
           simgrid::simix::unblock(self);
         });
       }
@@ -124,9 +124,9 @@ public:
     simcall_run_blocking([this, &exception, self]{
       try {
         // When the kernel future is ready...
-        this->future_.then_([this, self](simgrid::kernel::Future<T> value) {
+        this->future_.then_([this, self](std::shared_ptr<simgrid::kernel::FutureState<T>>&& value) {
           // ...store it the simix kernel and wake up.
-          this->future_ = std::move(value);
+          this->future_ = std::move(simgrid::kernel::Future<T>(value));
           simgrid::simix::unblock(self);
         });
       }
