@@ -1,6 +1,6 @@
 /* xbt.h - Public interface to the xbt (SimGrid's toolbox)                  */
 
-/* Copyright (c) 2004-2014. The SimGrid Team.
+/* Copyright (c) 2004-2017. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -12,7 +12,6 @@
 #include <xbt/misc.h>
 #include <xbt/sysdep.h>
 #include <xbt/str.h>
-#include <xbt/file.h>
 #include <xbt/function_types.h>
 
 #include <xbt/asserts.h>
@@ -22,8 +21,6 @@
 
 #include <xbt/dynar.h>
 #include <xbt/dict.h>
-#include <xbt/swag.h>
-#include <xbt/heap.h>
 #include <xbt/parmap.h>
 
 #include <xbt/config.h>
