@@ -1,4 +1,4 @@
-/* Copyright (c) 2014-2015. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2014-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -34,7 +34,7 @@ namespace xbt {
     }
     R operator()(P... args) const
     {
-      for (auto& handler : handlers_)
+      for (auto const& handler : handlers_)
         handler(args...);
     }
     void disconnect_all_slots()
