@@ -1,7 +1,6 @@
-/* Functions related to the java process instances.                         */
+/* Java bindings of the Synchronization API.                                */
 
-/* Copyright (c) 2012-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2012-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -10,8 +9,6 @@
 #define MSG_JSYNCHRO_H
 
 #include <jni.h>
-#include <simgrid/msg.h>
-#include <simgrid/simix.h>
 
 SG_BEGIN_DECL()
 
@@ -28,4 +25,4 @@ JNIEXPORT jboolean JNICALL Java_org_simgrid_msg_Semaphore_wouldBlock(JNIEnv * en
 JNIEXPORT void JNICALL Java_org_simgrid_msg_Semaphore_nativeFinalize(JNIEnv * env, jobject obj);
 
 SG_END_DECL()
-#endif                          /* !MSG_JPROCESS_H */
+#endif
