@@ -1,4 +1,4 @@
-/* Copyright (c) 2014-2016. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2014-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -20,7 +20,7 @@ import java.nio.file.Path;
  */
 public final class NativeLib {
 	private static boolean isNativeInited = false;
-	static Path tempDir = null; // where the embeeded libraries are unpacked before loading them
+	private static Path tempDir = null; // where the embeeded libraries are unpacked before loading them
 
 	/** A static-only "class" don't need no constructor */
 	private NativeLib() {
