@@ -4,12 +4,18 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "simgrid/jedule/jedule.hpp"
+#include "simgrid/host.h"
 #include "simgrid/s4u/NetZone.hpp"
 #include "xbt/asserts.h"
 #include <algorithm>
 
 #if SIMGRID_HAVE_JEDULE
 
+namespace {
+std::unordered_map<const char*, jed_container_t> host2_simgrid_parent_container;
+std::unordered_map<std::string, jed_container_t> container_name2container;
+}
+
 namespace simgrid {
 namespace jedule {
 Subset::Subset(int start_idx, int end_idx, Container* parent)
