@@ -7,9 +7,9 @@
 #define SIMIX_SYNCHRO_COMM_HPP
 
 #include "src/kernel/activity/ActivityImpl.hpp"
-#include "surf/surf.h"
+#include "surf/surf.hpp"
 
-typedef enum { SIMIX_COMM_SEND, SIMIX_COMM_RECEIVE, SIMIX_COMM_READY, SIMIX_COMM_DONE } e_smx_comm_type_t;
+enum e_smx_comm_type_t { SIMIX_COMM_SEND, SIMIX_COMM_RECEIVE, SIMIX_COMM_READY, SIMIX_COMM_DONE };
 
 namespace simgrid {
 namespace kernel {
@@ -46,7 +46,7 @@ expectations of the other side, too. See  */
   void (*copy_data_fun)(smx_activity_t, void*, size_t) = nullptr;
 
   /* Surf action data */
-  surf_action_t surf_comm   = nullptr; /* The Surf communication action encapsulated */
+  surf_action_t surfAction_ = nullptr; /* The Surf communication action encapsulated */
   surf_action_t src_timeout = nullptr; /* Surf's actions to instrument the timeouts */
   surf_action_t dst_timeout = nullptr; /* Surf's actions to instrument the timeouts */
   smx_actor_t src_proc      = nullptr;
