@@ -1,11 +1,11 @@
-/* Copyright (c) 2007-2016. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "src/kernel/activity/SynchroRaw.hpp"
+#include "src/simix/smx_synchro_private.hpp"
 #include "src/surf/surf_interface.hpp"
-#include "src/simix/smx_synchro_private.h"
 
 XBT_LOG_EXTERNAL_DEFAULT_CATEGORY(simix_synchro);
 
