@@ -1,4 +1,4 @@
-/* Copyright (c) 2016. The SimGrid Team.
+/* Copyright (c) 2016-2017. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -8,7 +8,7 @@
 
 #include <simgrid/kernel/future.hpp>
 
-#include "src/simix/smx_private.h"
+#include "src/simix/smx_private.hpp"
 
 namespace simgrid {
 namespace kernel {
