@@ -29,7 +29,8 @@ public:
     /* There can't be route in an Empty zone */
   }
 
-  void getGraph(xbt_graph_t graph, xbt_dict_t nodes, xbt_dict_t edges) override;
+  void getGraph(xbt_graph_t graph, std::map<std::string, xbt_node_t>* /*nodes*/,
+                std::map<std::string, xbt_edge_t>* /*edges*/) override;
 };
 }
 }
