@@ -21,7 +21,7 @@ NetPoint::NetPoint(std::string name, NetPoint::Type componentType, NetZoneImpl*
 {
   if (netzone_p != nullptr)
     id_ = netzone_p->addComponent(this);
-  simgrid::s4u::Engine::instance()->netpointRegister(this);
+  simgrid::s4u::Engine::getInstance()->netpointRegister(this);
   simgrid::kernel::routing::NetPoint::onCreation(this);
 }
 }
@@ -34,5 +34,5 @@ NetPoint::NetPoint(std::string name, NetPoint::Type componentType, NetZoneImpl*
  */
 simgrid::kernel::routing::NetPoint* sg_netpoint_by_name_or_null(const char* name)
 {
-  return simgrid::s4u::Engine::instance()->netpointByNameOrNull(name);
+  return simgrid::s4u::Engine::getInstance()->getNetpointByNameOrNull(name);
 }
