@@ -21,7 +21,7 @@ namespace routing {
 class XBT_PRIVATE TorusZone : public ClusterZone {
 public:
   explicit TorusZone(NetZone* father, std::string name);
-  void create_links_for_node(ClusterCreationArgs* cluster, int id, int rank, int position) override;
+  void create_links_for_node(ClusterCreationArgs* cluster, int id, int rank, unsigned int position) override;
   void getLocalRoute(NetPoint* src, NetPoint* dst, sg_platf_route_cbarg_t into, double* latency) override;
   void parse_specific_arguments(ClusterCreationArgs* cluster) override;
 
