@@ -6,7 +6,7 @@
 
 #include <libunwind.h>
 
-#include <xbt/sysdep.h>
+#include "xbt/sysdep.h"
 
 #include "src/mc/Frame.hpp"
 
@@ -34,4 +34,4 @@ void* Frame::frame_base(unw_cursor_t& unw_cursor) const
 }
 
 }
-}
\ No newline at end of file
+}
