@@ -15,15 +15,6 @@
 namespace simgrid {
 namespace mc {
 
-/** Can this requests can be executed?
- *
- *  Most requests are always enabled but WAIT and WAITANY
- *  are not always enabled: a WAIT where the communication does not
- *  have both a source and a destination yet is not enabled
- *  (unless timeout is enabled in the wait and enabeld in SimGridMC).
- */
-XBT_PRIVATE bool request_is_enabled(smx_simcall_t req);
-
 /** Execute everything which is invisible
  *
  *  Execute all the processes that are ready to run and all invisible simcalls
@@ -37,10 +28,18 @@ XBT_PRIVATE extern std::vector<double> processes_time;
 /** Execute a given simcall */
 XBT_PRIVATE void handle_simcall(smx_simcall_t req, int req_num);
 
-/** Check if the given simcall is visible
+/** Is the process ready to execute its simcall?
  *
- *  \return `TRUE` or `FALSE`
+ *  This is true if the request associated with the process is ready.
+ *
+ *  Most requests are always enabled but WAIT and WAITANY
+ *  are not always enabled: a WAIT where the communication does not
+ *  have both a source and a destination yet is not enabled
+ *  (unless timeout is enabled in the wait and enabeld in SimGridMC).
  */
+XBT_PRIVATE bool actor_is_enabled(smx_actor_t process);
+
+/** Check if the given simcall is visible */
 XBT_PRIVATE bool request_is_visible(smx_simcall_t req);
 
 }
