@@ -1,5 +1,4 @@
-/* Copyright (c) 2007-2015. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2007-2015. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -7,10 +6,7 @@
 #ifndef SIMGRID_MC_HASH_HPP
 #define SIMGRID_MC_HASH_HPP
 
-#include <cstdint>
-
-#include <xbt/base.h>
-
+#include "xbt/base.h"
 #include "src/mc/mc_forward.hpp"
 
 namespace simgrid {
