@@ -29,11 +29,10 @@ Channel::~Channel()
 int Channel::send(const void* message, size_t size) const
 {
   XBT_DEBUG("Send %s", MC_message_type_name(*(e_mc_message_type*)message));
-  while (::send(this->socket_, message, size, 0) == -1)
-    if (errno == EINTR)
-      continue;
-    else
+  while (::send(this->socket_, message, size, 0) == -1) {
+    if (errno != EINTR)
       return errno;
+  }
   return 0;
 }
 
