@@ -12,21 +12,20 @@
 
 #include <xbt/log.h>
 #include <xbt/mmalloc.h>
-#include <xbt/swag.h>
 #include <xbt/sysdep.h>
 
 #include <simgrid/modelchecker.h>
 
 #include "src/internal_config.h"
 
-#include "src/mc/mc_request.h"
+#include "src/mc/mc_request.hpp"
 #include "src/mc/remote/Client.hpp"
 #include "src/mc/remote/mc_protocol.h"
 
 #include "src/smpi/include/private.hpp"
 
 // We won't need those once the separation MCer/MCed is complete:
-#include "src/mc/mc_smx.h"
+#include "src/mc/mc_smx.hpp"
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_client, mc, "MC client logic");
 
@@ -83,7 +82,7 @@ Client* Client::initialize()
   return instance_.get();
 }
 
-void Client::handleDeadlockCheck(mc_message_t* msg)
+void Client::handleDeadlockCheck(s_mc_message_t* msg)
 {
   bool deadlock = false;
   if (not simix_global->process_list.empty()) {
@@ -96,10 +95,10 @@ void Client::handleDeadlockCheck(mc_message_t* msg)
   }
 
   // Send result:
-  mc_message_int_t answer{MC_MESSAGE_DEADLOCK_CHECK_REPLY, deadlock};
+  s_mc_message_int_t answer{MC_MESSAGE_DEADLOCK_CHECK_REPLY, deadlock};
   xbt_assert(channel_.send(answer) == 0, "Could not send response");
 }
-void Client::handleContinue(mc_message_t* msg)
+void Client::handleContinue(s_mc_message_t* msg)
 {
   /* Nothing to do */
 }
@@ -121,7 +120,7 @@ void Client::handleRestore(s_mc_message_restore_t* message)
 void Client::handleActorEnabled(s_mc_message_actor_enabled_t* msg)
 {
   bool res = simgrid::mc::actor_is_enabled(SIMIX_process_from_PID(msg->aid));
-  s_mc_message_int answer{MC_MESSAGE_ACTOR_ENABLED_REPLY, res};
+  s_mc_message_int_t answer{MC_MESSAGE_ACTOR_ENABLED_REPLY, res};
   channel_.send(answer);
 }
 
@@ -136,18 +135,18 @@ void Client::handleMessages()
     if (received_size < 0)
       xbt_die("Could not receive commands from the model-checker");
 
-    mc_message_t* message = (mc_message_t*)message_buffer;
+    s_mc_message_t* message = (s_mc_message_t*)message_buffer;
     switch (message->type) {
 
       case MC_MESSAGE_DEADLOCK_CHECK:
-        xbt_assert(received_size == sizeof(mc_message_t), "Unexpected size for DEADLOCK_CHECK (%zd != %zu)",
-                   received_size, sizeof(mc_message_t));
+        xbt_assert(received_size == sizeof(s_mc_message_t), "Unexpected size for DEADLOCK_CHECK (%zd != %zu)",
+                   received_size, sizeof(s_mc_message_t));
         handleDeadlockCheck(message);
         break;
 
       case MC_MESSAGE_CONTINUE:
-        xbt_assert(received_size == sizeof(mc_message_t), "Unexpected size for MESSAGE_CONTINUE (%zd != %zu)",
-                   received_size, sizeof(mc_message_t));
+        xbt_assert(received_size == sizeof(s_mc_message_t), "Unexpected size for MESSAGE_CONTINUE (%zd != %zu)",
+                   received_size, sizeof(s_mc_message_t));
         handleContinue(message);
         return;
 
@@ -159,8 +158,8 @@ void Client::handleMessages()
         break;
 
       case MC_MESSAGE_RESTORE:
-        xbt_assert(received_size == sizeof(mc_message_t), "Unexpected size for MESSAGE_RESTORE (%zd != %zu)",
-                   received_size, sizeof(mc_message_t));
+        xbt_assert(received_size == sizeof(s_mc_message_t), "Unexpected size for MESSAGE_RESTORE (%zd != %zu)",
+                   received_size, sizeof(s_mc_message_t));
         handleRestore((s_mc_message_restore_t*)message_buffer);
         break;
 
