@@ -1,13 +1,13 @@
-/* Copyright (c) 2015. The SimGrid Team.
+/* Copyright (c) 2015-2017. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
+#include <cerrno>
 #include <cstddef> // std::size_t
-#include <errno.h>
-#include <stdio.h> // perror
-#include <string.h>
+#include <cstdio>  // perror
+#include <cstring>
 
 #include <sys/socket.h>
 #include <sys/types.h>
@@ -46,6 +46,12 @@ const char* MC_message_type_name(e_mc_message_type type)
       return "SIMCALL_HANDLE";
     case MC_MESSAGE_ASSERTION_FAILED:
       return "ASSERTION_FAILED";
+
+    case MC_MESSAGE_ACTOR_ENABLED:
+      return "ACTOR_ENABLED";
+    case MC_MESSAGE_ACTOR_ENABLED_REPLY:
+      return "ACTOR_ENABLED_REPLY";
+
     default:
       return "?";
   }
