@@ -11,27 +11,19 @@
 
 #include <xbt/ex.hpp>
 
-#include "src/instr/instr_private.h"
-#include "src/msg/msg_private.h"
+#include "simgrid/plugins/live_migration.h"
+#include "src/instr/instr_private.hpp"
 #include "src/plugins/vm/VirtualMachineImpl.hpp"
 #include "src/plugins/vm/VmHostExt.hpp"
 
 #include "simgrid/host.h"
 #include "simgrid/simix.hpp"
+#include "xbt/string.hpp"
 
-SG_BEGIN_DECL()
-
-struct dirty_page {
-  double prev_clock;
-  double prev_remaining;
-  msg_task_t task;
-};
-typedef struct dirty_page s_dirty_page;
-typedef struct dirty_page* dirty_page_t;
+extern "C" {
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(msg_vm, msg, "Cloud-oriented parts of the MSG API");
 
-/* **** ******** GENERAL ********* **** */
 const char* MSG_vm_get_name(msg_vm_t vm)
 {
   return vm->getCname();
@@ -59,10 +51,19 @@ void MSG_vm_get_params(msg_vm_t vm, vm_params_t params)
   vm->getParameters(params);
 }
 
+void MSG_vm_set_ramsize(msg_vm_t vm, size_t size)
+{
+  vm->setRamsize(size);
+}
+size_t MSG_vm_get_ramsize(msg_vm_t vm)
+{
+  return vm->getRamsize();
+}
+
 /* **** Check state of a VM **** */
 static inline int __MSG_vm_is_state(msg_vm_t vm, e_surf_vm_state_t state)
 {
-  return vm->pimpl_vm_ != nullptr && vm->pimpl_vm_->getState() == state;
+  return vm->pimpl_vm_ != nullptr && vm->getState() == state;
 }
 
 /** @brief Returns whether the given VM has just created, not running.
@@ -113,16 +114,12 @@ msg_vm_t MSG_vm_create(msg_host_t pm, const char* name, int coreAmount, int rams
 
   /* For the moment, intensity_rate is the percentage against the migration bandwidth */
 
-  msg_vm_t vm = new simgrid::s4u::VirtualMachine(name, pm, coreAmount);
+  msg_vm_t vm = new simgrid::s4u::VirtualMachine(name, pm, coreAmount, static_cast<sg_size_t>(ramsize) * 1024 * 1024);
   s_vm_params_t params;
-  memset(&params, 0, sizeof(params));
-  params.ramsize = static_cast<sg_size_t>(ramsize) * 1024 * 1024;
-  params.devsize = 0;
-  params.skip_stage2 = 0;
   params.max_downtime = 0.03;
-  params.mig_speed = static_cast<double>(mig_netspeed) * 1024 * 1024; // mig_speed
+  params.mig_speed    = static_cast<double>(mig_netspeed) * 1024 * 1024; // mig_speed
   params.dp_intensity = static_cast<double>(dp_intensity) / 100;
-  params.dp_cap       = params.ramsize * 0.9; // assume working set memory is 90% of ramsize
+  params.dp_cap       = vm->getRamsize() * 0.9; // assume working set memory is 90% of ramsize
 
   XBT_DEBUG("migspeed : %f intensity mem : %d", params.mig_speed, dp_intensity);
   vm->setParameters(&params);
@@ -140,7 +137,11 @@ msg_vm_t MSG_vm_create_core(msg_host_t pm, const char* name)
   xbt_assert(sg_host_by_name(name) == nullptr,
              "Cannot create a VM named %s: this name is already used by an host or a VM", name);
 
-  return new simgrid::s4u::VirtualMachine(name, pm, 1);
+  msg_vm_t vm = new simgrid::s4u::VirtualMachine(name, pm, 1);
+  s_vm_params_t params;
+  memset(&params, 0, sizeof(params));
+  vm->setParameters(&params);
+  return vm;
 }
 /** @brief Create a new VM object with the default parameters, but with a specified amount of cores
  *  @ingroup msg_VMs*
@@ -152,7 +153,11 @@ msg_vm_t MSG_vm_create_multicore(msg_host_t pm, const char* name, int coreAmount
   xbt_assert(sg_host_by_name(name) == nullptr,
              "Cannot create a VM named %s: this name is already used by an host or a VM", name);
 
-  return new simgrid::s4u::VirtualMachine(name, pm, coreAmount);
+  msg_vm_t vm = new simgrid::s4u::VirtualMachine(name, pm, coreAmount);
+  s_vm_params_t params;
+  memset(&params, 0, sizeof(params));
+  vm->setParameters(&params);
+  return vm;
 }
 
 /** @brief Destroy a VM. Destroy the VM object from the simulation.
@@ -164,15 +169,14 @@ void MSG_vm_destroy(msg_vm_t vm)
     THROWF(vm_error, 0, "Cannot destroy VM '%s', which is migrating.", vm->getCname());
 
   /* First, terminate all processes on the VM if necessary */
-  if (MSG_vm_is_running(vm))
-    MSG_vm_shutdown(vm);
+  vm->shutdown();
 
   /* Then, destroy the VM object */
-  simgrid::simix::kernelImmediate([vm]() { vm->destroy(); });
+  vm->destroy();
 
   if (TRACE_msg_vm_is_enabled()) {
-    container_t container = PJ_container_get(vm->getCname());
-    PJ_container_remove_from_parent(container);
+    container_t container = simgrid::instr::Container::byName(vm->getName());
+    container->removeFromParent();
     delete container;
   }
 }
@@ -186,10 +190,9 @@ void MSG_vm_start(msg_vm_t vm)
 {
   vm->start();
   if (TRACE_msg_vm_is_enabled()) {
-    container_t vm_container = PJ_container_get(vm->getCname());
-    simgrid::instr::Type* type = vm_container->type_->getChild("MSG_VM_STATE");
-    simgrid::instr::Value* val = simgrid::instr::Value::get_or_new("start", "0 0 1", type); // start is blue
-    new simgrid::instr::PushStateEvent(MSG_get_clock(), vm_container, type, val);
+    simgrid::instr::StateType* state = simgrid::instr::Container::byName(vm->getName())->getState("MSG_VM_STATE");
+    state->addEntityValue("start", "0 0 1"); // start is blue
+    state->pushEvent("start");
   }
 }
 
@@ -202,11 +205,7 @@ void MSG_vm_start(msg_vm_t vm)
  */
 void MSG_vm_shutdown(msg_vm_t vm)
 {
-  smx_actor_t issuer = SIMIX_process_self();
-  simgrid::simix::kernelImmediate([vm, issuer]() { vm->pimpl_vm_->shutdown(issuer); });
-
-  // Make sure that processes in the VM are killed in this scheduling round before processing (eg with the VM destroy)
-  MSG_process_sleep(0.);
+  vm->shutdown();
 }
 
 static std::string get_mig_process_tx_name(msg_vm_t vm, msg_host_t src_pm, msg_host_t dst_pm)
@@ -232,9 +231,9 @@ struct migration_session {
 
   /* The miration_rx process uses mbox_ctl to let the caller of do_migration()
    * know the completion of the migration. */
-  char *mbox_ctl;
+  std::string mbox_ctl;
   /* The migration_rx and migration_tx processes use mbox to transfer migration data. */
-  char *mbox;
+  std::string mbox;
 };
 
 static int migration_rx_fun(int argc, char *argv[])
@@ -242,14 +241,14 @@ static int migration_rx_fun(int argc, char *argv[])
   XBT_DEBUG("mig: rx_start");
 
   // The structure has been created in the do_migration function and should only be freed in the same place ;)
-  struct migration_session* ms = static_cast<migration_session*>(MSG_process_get_data(MSG_process_self()));
+  migration_session* ms = static_cast<migration_session*>(MSG_process_get_data(MSG_process_self()));
 
   bool received_finalize = false;
 
   std::string finalize_task_name = get_mig_task_name(ms->vm, ms->src_pm, ms->dst_pm, 3);
   while (not received_finalize) {
     msg_task_t task = nullptr;
-    int ret         = MSG_task_recv(&task, ms->mbox);
+    int ret         = MSG_task_recv(&task, ms->mbox.c_str());
 
     if (ret != MSG_OK) {
       // An error occurred, clean the code and return
@@ -276,11 +275,11 @@ static int migration_rx_fun(int argc, char *argv[])
   simgrid::simix::kernelImmediate([vm, dst_pm]() {
     /* Update the vm location */
     /* precopy migration makes the VM temporally paused */
-    xbt_assert(vm->pimpl_vm_->getState() == SURF_VM_STATE_SUSPENDED);
+    xbt_assert(vm->getState() == SURF_VM_STATE_SUSPENDED);
 
     /* Update the vm location and resume it */
     vm->pimpl_vm_->setPm(dst_pm);
-    vm->pimpl_vm_->resume();
+    vm->resume();
   });
 
 
@@ -290,34 +289,30 @@ static int migration_rx_fun(int argc, char *argv[])
 
   if (TRACE_msg_vm_is_enabled()) {
     static long long int counter = 0;
-    char key[INSTR_DEFAULT_STR_SIZE];
-    snprintf(key, INSTR_DEFAULT_STR_SIZE, "%lld", counter);
+    std::string key              = std::to_string(counter);
     counter++;
 
     // start link
-    container_t msg = PJ_container_get(vm->getCname());
-    simgrid::instr::Type* type = PJ_type_get_root()->getChild("MSG_VM_LINK");
-    new simgrid::instr::StartLinkEvent(MSG_get_clock(), PJ_container_get_root(), type, msg, "M", key);
+    container_t msg = simgrid::instr::Container::byName(vm->getName());
+    simgrid::instr::Container::getRoot()->getLink("MSG_VM_LINK")->startEvent(msg, "M", key);
 
     // destroy existing container of this vm
-    container_t existing_container = PJ_container_get(vm->getCname());
-    PJ_container_remove_from_parent(existing_container);
+    container_t existing_container = simgrid::instr::Container::byName(vm->getName());
+    existing_container->removeFromParent();
     delete existing_container;
 
     // create new container on the new_host location
-    new simgrid::instr::Container(vm->getCname(), simgrid::instr::INSTR_MSG_VM,
-                                  PJ_container_get(ms->dst_pm->getCname()));
+    new simgrid::instr::Container(vm->getCname(), "MSG_VM", simgrid::instr::Container::byName(ms->dst_pm->getName()));
 
     // end link
-    msg  = PJ_container_get(vm->getCname());
-    type = PJ_type_get_root()->getChild("MSG_VM_LINK");
-    new simgrid::instr::EndLinkEvent(MSG_get_clock(), PJ_container_get_root(), type, msg, "M", key);
+    msg  = simgrid::instr::Container::byName(vm->getName());
+    simgrid::instr::Container::getRoot()->getLink("MSG_VM_LINK")->endEvent(msg, "M", key);
   }
 
   // Inform the SRC that the migration has been correctly performed
   std::string task_name = get_mig_task_name(ms->vm, ms->src_pm, ms->dst_pm, 4);
   msg_task_t task       = MSG_task_create(task_name.c_str(), 0, 0, nullptr);
-  msg_error_t ret = MSG_task_send(task, ms->mbox_ctl);
+  msg_error_t ret       = MSG_task_send(task, ms->mbox_ctl.c_str());
   if(ret == MSG_HOST_FAILURE){
     // The DST has crashed, this is a problem has the VM since we are not sure whether SRC is considering that the VM
     // has been correctly migrated on the DST node
@@ -332,119 +327,9 @@ static int migration_rx_fun(int argc, char *argv[])
   return 0;
 }
 
-static void start_dirty_page_tracking(msg_vm_t vm)
-{
-  vm->pimpl_vm_->dp_enabled = 1;
-  if (vm->pimpl_vm_->dp_objs.empty())
-    return;
-
-  for (auto const& elm : vm->pimpl_vm_->dp_objs) {
-    dirty_page_t dp    = elm.second;
-    double remaining = MSG_task_get_flops_amount(dp->task);
-    dp->prev_clock = MSG_get_clock();
-    dp->prev_remaining = remaining;
-    XBT_DEBUG("%s@%s remaining %f", elm.first.c_str(), vm->getCname(), remaining);
-  }
-}
-
-static void stop_dirty_page_tracking(msg_vm_t vm)
-{
-  vm->pimpl_vm_->dp_enabled = 0;
-}
-
-static double get_computed(const char* key, msg_vm_t vm, dirty_page_t dp, double remaining, double clock)
-{
-  double computed = dp->prev_remaining - remaining;
-  double duration = clock - dp->prev_clock;
-
-  XBT_DEBUG("%s@%s: computed %f ops (remaining %f -> %f) in %f secs (%f -> %f)", key, vm->getCname(), computed,
-            dp->prev_remaining, remaining, duration, dp->prev_clock, clock);
-
-  return computed;
-}
-
-static double lookup_computed_flop_counts(msg_vm_t vm, int stage_for_fancy_debug, int stage2_round_for_fancy_debug)
-{
-  double total = 0;
-
-  for (auto const& elm : vm->pimpl_vm_->dp_objs) {
-    const char* key  = elm.first.c_str();
-    dirty_page_t dp  = elm.second;
-    double remaining = MSG_task_get_flops_amount(dp->task);
-
-    double clock = MSG_get_clock();
-
-    total += get_computed(key, vm, dp, remaining, clock);
-
-    dp->prev_remaining = remaining;
-    dp->prev_clock = clock;
-  }
-
-  total += vm->pimpl_vm_->dp_updated_by_deleted_tasks;
-
-  XBT_DEBUG("mig-stage%d.%d: computed %f flop_counts (including %f by deleted tasks)", stage_for_fancy_debug,
-            stage2_round_for_fancy_debug, total, vm->pimpl_vm_->dp_updated_by_deleted_tasks);
-
-  vm->pimpl_vm_->dp_updated_by_deleted_tasks = 0;
-
-  return total;
-}
-
-// TODO Is this code redundant with the information provided by
-// msg_process_t MSG_process_create(const char *name, xbt_main_func_t code, void *data, msg_host_t host)
-/** @brief take care of the dirty page tracking, in case we're adding a task to a migrating VM */
-void MSG_host_add_task(msg_host_t host, msg_task_t task)
-{
-  simgrid::s4u::VirtualMachine* vm = dynamic_cast<simgrid::s4u::VirtualMachine*>(host);
-  if (vm == nullptr)
-    return;
-
-  double remaining = MSG_task_get_flops_amount(task);
-  char *key = bprintf("%s-%p", task->name, task);
-
-  dirty_page_t dp = xbt_new0(s_dirty_page, 1);
-  dp->task = task;
-  if (vm->pimpl_vm_->dp_enabled) {
-    dp->prev_clock = MSG_get_clock();
-    dp->prev_remaining = remaining;
-  }
-  vm->pimpl_vm_->dp_objs.insert({key, dp});
-  XBT_DEBUG("add %s on %s (remaining %f, dp_enabled %d)", key, host->getCname(), remaining, vm->pimpl_vm_->dp_enabled);
-
-  xbt_free(key);
-}
-
-void MSG_host_del_task(msg_host_t host, msg_task_t task)
-{
-  simgrid::s4u::VirtualMachine* vm = dynamic_cast<simgrid::s4u::VirtualMachine*>(host);
-  if (vm == nullptr)
-    return;
-
-  char *key = bprintf("%s-%p", task->name, task);
-  dirty_page_t dp = nullptr;
-  if (vm->pimpl_vm_->dp_objs.find(key) != vm->pimpl_vm_->dp_objs.end())
-    dp = vm->pimpl_vm_->dp_objs.at(key);
-  xbt_assert(dp && dp->task == task);
-
-  /* If we are in the middle of dirty page tracking, we record how much computation has been done until now, and keep
-   * the information for the lookup_() function that will called soon. */
-  if (vm->pimpl_vm_->dp_enabled) {
-    double remaining = MSG_task_get_flops_amount(task);
-    double clock = MSG_get_clock();
-    double updated = get_computed(key, vm, dp, remaining, clock); // was host instead of vm
-
-    vm->pimpl_vm_->dp_updated_by_deleted_tasks += updated;
-  }
-
-  vm->pimpl_vm_->dp_objs.erase(key);
-  xbt_free(dp);
-
-  XBT_DEBUG("del %s on %s", key, host->getCname());
-  xbt_free(key);
-}
-
-static sg_size_t send_migration_data(msg_vm_t vm, msg_host_t src_pm, msg_host_t dst_pm, sg_size_t size, char* mbox,
-                                     int stage, int stage2_round, double mig_speed, double timeout)
+static sg_size_t send_migration_data(msg_vm_t vm, msg_host_t src_pm, msg_host_t dst_pm, sg_size_t size,
+                                     const std::string& mbox, int stage, int stage2_round, double mig_speed,
+                                     double timeout)
 {
   sg_size_t sent = 0;
   std::string task_name = get_mig_task_name(vm, src_pm, dst_pm, stage);
@@ -454,9 +339,9 @@ static sg_size_t send_migration_data(msg_vm_t vm, msg_host_t src_pm, msg_host_t
 
   msg_error_t ret;
   if (mig_speed > 0)
-    ret = MSG_task_send_with_timeout_bounded(task, mbox, timeout, mig_speed);
+    ret = MSG_task_send_with_timeout_bounded(task, mbox.c_str(), timeout, mig_speed);
   else
-    ret = MSG_task_send(task, mbox);
+    ret = MSG_task_send(task, mbox.c_str());
 
   if (ret == MSG_OK) {
     sent = size;
@@ -507,24 +392,22 @@ static int migration_tx_fun(int argc, char *argv[])
   XBT_DEBUG("mig: tx_start");
 
   // Note that the ms structure has been allocated in do_migration and hence should be freed in the same function ;)
-  migration_session *ms = static_cast<migration_session *>(MSG_process_get_data(MSG_process_self()));
+  migration_session* ms = static_cast<migration_session*>(MSG_process_get_data(MSG_process_self()));
 
-  double host_speed = ms->vm->pimpl_vm_->getPm()->getSpeed();
+  double host_speed = ms->vm->getPm()->getSpeed();
   s_vm_params_t params;
   ms->vm->getParameters(&params);
-  const sg_size_t ramsize   = params.ramsize;
-  const sg_size_t devsize   = params.devsize;
-  const int skip_stage1     = params.skip_stage1;
-  int skip_stage2           = params.skip_stage2;
+  const sg_size_t ramsize   = ms->vm->getRamsize();
   const double dp_rate      = host_speed ? (params.mig_speed * params.dp_intensity) / host_speed : 1;
   const double dp_cap       = params.dp_cap;
   const double mig_speed    = params.mig_speed;
   double max_downtime       = params.max_downtime;
 
   double mig_timeout = 10000000.0;
+  bool skip_stage2   = false;
 
-  double remaining_size = static_cast<double>(ramsize + devsize);
-  double threshold = 0.0;
+  size_t remaining_size = ramsize;
+  size_t threshold      = 0.0;
 
   /* check parameters */
   if (ramsize == 0)
@@ -536,48 +419,44 @@ static int migration_tx_fun(int argc, char *argv[])
   }
 
   /* Stage1: send all memory pages to the destination. */
-  XBT_DEBUG("mig-stage1: remaining_size %f", remaining_size);
-  start_dirty_page_tracking(ms->vm);
+  XBT_DEBUG("mig-stage1: remaining_size %zu", remaining_size);
+  sg_vm_start_dirty_page_tracking(ms->vm);
 
   double computed_during_stage1 = 0;
-  if (not skip_stage1) {
-    double clock_prev_send = MSG_get_clock();
+  double clock_prev_send        = MSG_get_clock();
 
-    try {
-      /* At stage 1, we do not need timeout. We have to send all the memory pages even though the duration of this
-       * transfer exceeds the timeout value. */
-      XBT_VERB("Stage 1: Gonna send %llu bytes", ramsize);
-      sg_size_t sent = send_migration_data(ms->vm, ms->src_pm, ms->dst_pm, ramsize, ms->mbox, 1, 0, mig_speed, -1);
-      remaining_size -= sent;
-      computed_during_stage1 = lookup_computed_flop_counts(ms->vm, 1, 0);
+  try {
+    /* At stage 1, we do not need timeout. We have to send all the memory pages even though the duration of this
+     * transfer exceeds the timeout value. */
+    XBT_VERB("Stage 1: Gonna send %llu bytes", ramsize);
+    sg_size_t sent = send_migration_data(ms->vm, ms->src_pm, ms->dst_pm, ramsize, ms->mbox, 1, 0, mig_speed, -1);
+    remaining_size -= sent;
+    computed_during_stage1 = sg_vm_lookup_computed_flops(ms->vm);
 
-      if (sent < ramsize) {
-        XBT_VERB("mig-stage1: timeout, force moving to stage 3");
-        skip_stage2 = 1;
-      } else if (sent > ramsize)
-        XBT_CRITICAL("bug");
+    if (sent < ramsize) {
+      XBT_VERB("mig-stage1: timeout, force moving to stage 3");
+      skip_stage2 = true;
+    } else if (sent > ramsize)
+      XBT_CRITICAL("bug");
 
-    }
-    catch (xbt_ex& e) {
-      //hostfailure (if you want to know whether this is the SRC or the DST check directly in send_migration_data code)
-      // Stop the dirty page tracking an return (there is no memory space to release)
-      stop_dirty_page_tracking(ms->vm);
-      return 0;
-    }
-
-    double clock_post_send = MSG_get_clock();
-    mig_timeout -= (clock_post_send - clock_prev_send);
-    if (mig_timeout < 0) {
-      XBT_VERB("The duration of stage 1 exceeds the timeout value, skip stage 2");
-      skip_stage2 = 1;
-    }
-
-    /* estimate bandwidth */
-    double bandwidth = ramsize / (clock_post_send - clock_prev_send);
-    threshold        = bandwidth * max_downtime;
-    XBT_DEBUG("actual bandwidth %f (MB/s), threshold %f", bandwidth / 1024 / 1024, threshold);
+  } catch (xbt_ex& e) {
+    // hostfailure (if you want to know whether this is the SRC or the DST check directly in send_migration_data code)
+    // Stop the dirty page tracking an return (there is no memory space to release)
+    sg_vm_stop_dirty_page_tracking(ms->vm);
+    return 0;
   }
 
+  double clock_post_send = MSG_get_clock();
+  mig_timeout -= (clock_post_send - clock_prev_send);
+  if (mig_timeout < 0) {
+    XBT_VERB("The duration of stage 1 exceeds the timeout value, skip stage 2");
+    skip_stage2 = true;
+  }
+
+  /* estimate bandwidth */
+  double bandwidth = ramsize / (clock_post_send - clock_prev_send);
+  threshold        = bandwidth * max_downtime;
+  XBT_DEBUG("actual bandwidth %f (MB/s), threshold %zu", bandwidth / 1024 / 1024, threshold);
 
   /* Stage2: send update pages iteratively until the size of remaining states becomes smaller than threshold value. */
   if (not skip_stage2) {
@@ -590,7 +469,7 @@ static int migration_tx_fun(int argc, char *argv[])
         /* just after stage1, nothing has been updated. But, we have to send the data updated during stage1 */
         updated_size = get_updated_size(computed_during_stage1, dp_rate, dp_cap);
       } else {
-        double computed = lookup_computed_flop_counts(ms->vm, 2, stage2_round);
+        double computed = sg_vm_lookup_computed_flops(ms->vm);
         updated_size    = get_updated_size(computed, dp_rate, dp_cap);
       }
 
@@ -599,7 +478,7 @@ static int migration_tx_fun(int argc, char *argv[])
 
       /* Check whether the remaining size is below the threshold value. If so, move to stage 3. */
       remaining_size += updated_size;
-      XBT_DEBUG("mig-stage2.%d: remaining_size %f (%s threshold %f)", stage2_round, remaining_size,
+      XBT_DEBUG("mig-stage2.%d: remaining_size %zu (%s threshold %zu)", stage2_round, remaining_size,
                 (remaining_size < threshold) ? "<" : ">", threshold);
       if (remaining_size < threshold)
         break;
@@ -614,7 +493,7 @@ static int migration_tx_fun(int argc, char *argv[])
         // hostfailure (if you want to know whether this is the SRC or the DST check directly in send_migration_data
         // code)
         // Stop the dirty page tracking an return (there is no memory space to release)
-        stop_dirty_page_tracking(ms->vm);
+        sg_vm_stop_dirty_page_tracking(ms->vm);
         return 0;
       }
       double clock_post_send = MSG_get_clock();
@@ -623,7 +502,7 @@ static int migration_tx_fun(int argc, char *argv[])
         /* timeout did not happen */
         double bandwidth = updated_size / (clock_post_send - clock_prev_send);
         threshold        = bandwidth * max_downtime;
-        XBT_DEBUG("actual bandwidth %f, threshold %f", bandwidth / 1024 / 1024, threshold);
+        XBT_DEBUG("actual bandwidth %f, threshold %zu", bandwidth / 1024 / 1024, threshold);
         remaining_size -= sent;
         stage2_round += 1;
         mig_timeout -= (clock_post_send - clock_prev_send);
@@ -636,7 +515,7 @@ static int migration_tx_fun(int argc, char *argv[])
                  updated_size, (clock_post_send - clock_prev_send));
         remaining_size -= sent;
 
-        double computed = lookup_computed_flop_counts(ms->vm, 2, stage2_round);
+        double computed = sg_vm_lookup_computed_flops(ms->vm);
         updated_size    = get_updated_size(computed, dp_rate, dp_cap);
         remaining_size += updated_size;
         break;
@@ -646,22 +525,21 @@ static int migration_tx_fun(int argc, char *argv[])
   }
 
   /* Stage3: stop the VM and copy the rest of states. */
-  XBT_DEBUG("mig-stage3: remaining_size %f", remaining_size);
+  XBT_DEBUG("mig-stage3: remaining_size %zu", remaining_size);
   simgrid::vm::VirtualMachineImpl* pimpl = ms->vm->pimpl_vm_;
   pimpl->setState(SURF_VM_STATE_RUNNING); // FIXME: this bypass of the checks in suspend() is not nice
   pimpl->isMigrating = false;             // FIXME: this bypass of the checks in suspend() is not nice
   pimpl->suspend(SIMIX_process_self());
-  stop_dirty_page_tracking(ms->vm);
+  sg_vm_stop_dirty_page_tracking(ms->vm);
 
   try {
-    XBT_DEBUG("Stage 3: Gonna send %f bytes", remaining_size);
-    send_migration_data(ms->vm, ms->src_pm, ms->dst_pm, static_cast<sg_size_t>(remaining_size), ms->mbox, 3, 0,
-                        mig_speed, -1);
+    XBT_DEBUG("Stage 3: Gonna send %zu bytes", remaining_size);
+    send_migration_data(ms->vm, ms->src_pm, ms->dst_pm, remaining_size, ms->mbox, 3, 0, mig_speed, -1);
   }
   catch(xbt_ex& e) {
     //hostfailure (if you want to know whether this is the SRC or the DST check directly in send_migration_data code)
     // Stop the dirty page tracking an return (there is no memory space to release)
-    ms->vm->pimpl_vm_->resume();
+    ms->vm->resume();
     return 0;
   }
 
@@ -693,7 +571,7 @@ void MSG_vm_migrate(msg_vm_t vm, msg_host_t dst_pm)
    * The second one would be easier.
    */
 
-  msg_host_t src_pm = vm->pimpl_vm_->getPm();
+  msg_host_t src_pm = vm->getPm();
 
   if (src_pm->isOff())
     THROWF(vm_error, 0, "Cannot migrate VM '%s' from host '%s', which is offline.", vm->getCname(), src_pm->getCname());
@@ -706,34 +584,32 @@ void MSG_vm_migrate(msg_vm_t vm, msg_host_t dst_pm)
 
   vm->pimpl_vm_->isMigrating = true;
 
-  struct migration_session *ms = xbt_new(struct migration_session, 1);
-  ms->vm = vm;
-  ms->src_pm = src_pm;
-  ms->dst_pm = dst_pm;
+  migration_session ms;
+  ms.vm     = vm;
+  ms.src_pm = src_pm;
+  ms.dst_pm = dst_pm;
 
   /* We have two mailboxes. mbox is used to transfer migration data between source and destination PMs. mbox_ctl is used
    * to detect the completion of a migration. The names of these mailboxes must not conflict with others. */
-  ms->mbox_ctl = bprintf("__mbox_mig_ctl:%s(%s-%s)", vm->getCname(), src_pm->getCname(), dst_pm->getCname());
-  ms->mbox     = bprintf("__mbox_mig_src_dst:%s(%s-%s)", vm->getCname(), src_pm->getCname(), dst_pm->getCname());
+  ms.mbox_ctl =
+      simgrid::xbt::string_printf("__mbox_mig_ctl:%s(%s-%s)", vm->getCname(), src_pm->getCname(), dst_pm->getCname());
+  ms.mbox = simgrid::xbt::string_printf("__mbox_mig_src_dst:%s(%s-%s)", vm->getCname(), src_pm->getCname(),
+                                        dst_pm->getCname());
 
   std::string pr_rx_name = get_mig_process_rx_name(vm, src_pm, dst_pm);
   std::string pr_tx_name = get_mig_process_tx_name(vm, src_pm, dst_pm);
 
-  MSG_process_create(pr_rx_name.c_str(), migration_rx_fun, ms, dst_pm);
+  MSG_process_create(pr_rx_name.c_str(), migration_rx_fun, &ms, dst_pm);
 
-  MSG_process_create(pr_tx_name.c_str(), migration_tx_fun, ms, src_pm);
+  MSG_process_create(pr_tx_name.c_str(), migration_tx_fun, &ms, src_pm);
 
   /* wait until the migration have finished or on error has occurred */
   XBT_DEBUG("wait for reception of the final ACK (i.e. migration has been correctly performed");
   msg_task_t task = nullptr;
-  msg_error_t ret = MSG_task_receive(&task, ms->mbox_ctl);
+  msg_error_t ret = MSG_task_receive(&task, ms.mbox_ctl.c_str());
 
   vm->pimpl_vm_->isMigrating = false;
 
-  xbt_free(ms->mbox_ctl);
-  xbt_free(ms->mbox);
-  xbt_free(ms);
-
   if (ret == MSG_HOST_FAILURE) {
     // Note that since the communication failed, the owner did not change and the task should be destroyed on the
     // other side. Hence, just throw the execption
@@ -763,16 +639,11 @@ void MSG_vm_migrate(msg_vm_t vm, msg_host_t dst_pm)
  */
 void MSG_vm_suspend(msg_vm_t vm)
 {
-  smx_actor_t issuer = SIMIX_process_self();
-  simgrid::simix::kernelImmediate([vm, issuer]() { vm->pimpl_vm_->suspend(issuer); });
-
-  XBT_DEBUG("vm_suspend done");
-
+  vm->suspend();
   if (TRACE_msg_vm_is_enabled()) {
-    container_t vm_container = PJ_container_get(vm->getCname());
-    simgrid::instr::Type* type = vm_container->type_->getChild("MSG_VM_STATE");
-    simgrid::instr::Value* val = simgrid::instr::Value::get_or_new("suspend", "1 0 0", type); // suspend is red
-    new simgrid::instr::PushStateEvent(MSG_get_clock(), vm_container, type, val);
+    simgrid::instr::StateType* state = simgrid::instr::Container::byName(vm->getName())->getState("MSG_VM_STATE");
+    state->addEntityValue("suspend", "1 0 0"); // suspend is red
+    state->pushEvent("suspend");
   }
 }
 
@@ -783,13 +654,9 @@ void MSG_vm_suspend(msg_vm_t vm)
  */
 void MSG_vm_resume(msg_vm_t vm)
 {
-  vm->pimpl_vm_->resume();
-
-  if (TRACE_msg_vm_is_enabled()) {
-    container_t vm_container = PJ_container_get(vm->getCname());
-    simgrid::instr::Type* type = vm_container->type_->getChild("MSG_VM_STATE");
-    new simgrid::instr::PopStateEvent(MSG_get_clock(), vm_container, type);
-  }
+  vm->resume();
+  if (TRACE_msg_vm_is_enabled())
+    simgrid::instr::Container::byName(vm->getName())->getState("MSG_VM_STATE")->popEvent();
 }
 
 /** @brief Get the physical host of a given VM.
@@ -800,35 +667,8 @@ msg_host_t MSG_vm_get_pm(msg_vm_t vm)
   return vm->getPm();
 }
 
-/** @brief Set a CPU bound for a given VM.
- *  @ingroup msg_VMs
- *
- * 1. Note that in some cases MSG_task_set_bound() may not intuitively work for VMs.
- *
- * For example,
- *  On PM0, there are Task1 and VM0.
- *  On VM0, there is Task2.
- * Now we bound 75% to Task1\@PM0 and bound 25% to Task2\@VM0.
- * Then,
- *  Task1\@PM0 gets 50%.
- *  Task2\@VM0 gets 25%.
- * This is NOT 75% for Task1\@PM0 and 25% for Task2\@VM0, respectively.
- *
- * This is because a VM has the dummy CPU action in the PM layer. Putting a task on the VM does not affect the bound of
- * the dummy CPU action. The bound of the dummy CPU action is unlimited.
- *
- * There are some solutions for this problem. One option is to update the bound of the dummy CPU action automatically.
- * It should be the sum of all tasks on the VM. But, this solution might be costly, because we have to scan all tasks
- * on the VM in share_resource() or we have to trap both the start and end of task execution.
- *
- * The current solution is to use MSG_vm_set_bound(), which allows us to directly set the bound of the dummy CPU action.
- *
- * 2. Note that bound == 0 means no bound (i.e., unlimited). But, if a host has multiple CPU cores, the CPU share of a
- *    computation task (or a VM) never exceeds the capacity of a CPU core.
- */
 void MSG_vm_set_bound(msg_vm_t vm, double bound)
 {
-  simgrid::simix::kernelImmediate([vm, bound]() { vm->pimpl_vm_->setBound(bound); });
+  vm->setBound(bound);
+}
 }
-
-SG_END_DECL()
