@@ -12,12 +12,9 @@ namespace simgrid {
 namespace vm {
 simgrid::xbt::Extension<s4u::Host, VmHostExt> VmHostExt::EXTENSION_ID;
 
-VmHostExt::~VmHostExt()
-{
-}
 void VmHostExt::ensureVmExtInstalled()
 {
-  if (!EXTENSION_ID.valid())
+  if (not EXTENSION_ID.valid())
     EXTENSION_ID = simgrid::s4u::Host::extension_create<VmHostExt>();
 }
 }
