@@ -15,9 +15,16 @@ XBT_LOG_NEW_DEFAULT_SUBCATEGORY(s4u_activity,s4u,"S4U activities");
 namespace simgrid {
 namespace s4u {
 
-void Activity::setRemains(double remains) {
+double Activity::getRemains()
+{
+  return remains_;
+}
+
+Activity* Activity::setRemains(double remains)
+{
   xbt_assert(state_ == inited, "Cannot change the remaining amount of work once the Activity is started");
   remains_ = remains;
+  return this;
 }
 
 }
