@@ -14,9 +14,9 @@
 #include "simgrid/s4u/Storage.hpp"
 #include "simgrid/simix.hpp"
 #include "src/kernel/routing/NetPoint.hpp"
-#include "src/msg/msg_private.h"
+#include "src/msg/msg_private.hpp"
 #include "src/simix/ActorImpl.hpp"
-#include "src/simix/smx_private.h"
+#include "src/simix/smx_private.hpp"
 #include "src/surf/HostImpl.hpp"
 #include "src/surf/cpu_interface.hpp"
 #include "xbt/log.h"
@@ -81,6 +81,10 @@ Host* Host::by_name(std::string name)
 {
   return host_list.at(name); // Will raise a std::out_of_range if the host does not exist
 }
+Host* Host::by_name(const char* name)
+{
+  return host_list.at(std::string(name)); // Will raise a std::out_of_range if the host does not exist
+}
 Host* Host::by_name_or_null(const char* name)
 {
   return by_name_or_null(std::string(name));
@@ -134,10 +138,8 @@ int Host::getPstatesCount() const
  */
 void Host::actorList(std::vector<ActorPtr>* whereto)
 {
-  smx_actor_t actor = NULL;
-  xbt_swag_foreach(actor, this->extension<simgrid::simix::Host>()->process_list)
-  {
-    whereto->push_back(actor->ciface());
+  for (auto& actor : this->extension<simgrid::simix::Host>()->process_list) {
+    whereto->push_back(actor.ciface());
   }
 }
 
@@ -153,23 +155,23 @@ void Host::actorList(std::vector<ActorPtr>* whereto)
  * walk through the routing components tree and find a route between hosts
  * by calling each "get_route" function in each routing component.
  */
-void Host::routeTo(Host* dest, std::vector<Link*>* links, double* latency)
+void Host::routeTo(Host* dest, std::vector<Link*>& links, double* latency)
 {
   std::vector<surf::LinkImpl*> linkImpls;
-  this->routeTo(dest, &linkImpls, latency);
+  this->routeTo(dest, linkImpls, latency);
   for (surf::LinkImpl* const& l : linkImpls)
-    links->push_back(&l->piface_);
+    links.push_back(&l->piface_);
 }
 
 /** @brief Just like Host::routeTo, but filling an array of link implementations */
-void Host::routeTo(Host* dest, std::vector<surf::LinkImpl*>* links, double* latency)
+void Host::routeTo(Host* dest, std::vector<surf::LinkImpl*>& links, double* latency)
 {
   simgrid::kernel::routing::NetZoneImpl::getGlobalRoute(pimpl_netpoint, dest->pimpl_netpoint, links, latency);
   if (XBT_LOG_ISENABLED(surf_route, xbt_log_priority_debug)) {
     XBT_CDEBUG(surf_route, "Route from '%s' to '%s' (latency: %f):", getCname(), dest->getCname(),
                (latency == nullptr ? -1 : *latency));
-    for (auto const& link : *links)
-      XBT_CDEBUG(surf_route, "Link %s", link->cname());
+    for (auto const& link : links)
+      XBT_CDEBUG(surf_route, "Link %s", link->getCname());
   }
 }
 
@@ -193,9 +195,8 @@ void Host::setProperty(std::string key, std::string value)
 /** Get the processes attached to the host */
 void Host::getProcesses(std::vector<ActorPtr>* list)
 {
-  smx_actor_t actor = NULL;
-  xbt_swag_foreach(actor, this->extension<simgrid::simix::Host>()->process_list) {
-    list->push_back(actor->iface());
+  for (auto& actor : this->extension<simgrid::simix::Host>()->process_list) {
+    list->push_back(actor.iface());
   }
 }
 
@@ -264,5 +265,10 @@ void Host::execute(double flops)
   simcall_execution_wait(s);
 }
 
+double Host::getLoad()
+{
+  return this->pimpl_cpu->getLoad();
+}
+
 } // namespace simgrid
 } // namespace s4u
