@@ -3,23 +3,24 @@
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include "../surf/StorageImpl.hpp"
 #include "simgrid/s4u/Host.hpp"
 #include "simgrid/s4u/Storage.hpp"
 #include "simgrid/simix.hpp"
+#include "src/plugins/file_system/FileSystem.hpp"
+#include "src/surf/StorageImpl.hpp"
 #include <unordered_map>
 
 namespace simgrid {
+namespace xbt {
+template class Extendable<simgrid::s4u::Storage>;
+}
+
 namespace s4u {
 
-std::map<std::string, Storage*>* allStorages()
+void getStorageList(std::map<std::string, Storage*>* whereTo)
 {
-  std::unordered_map<std::string, surf::StorageImpl*>* map = surf::StorageImpl::storagesMap();
-  std::map<std::string, Storage*>* res                     = new std::map<std::string, Storage*>;
-  for (auto const& s : *map)
-    res->insert({s.first, &(s.second->piface_)}); // Convert each entry into its interface
-
-  return res;
+  for (auto const& s : *surf::StorageImpl::storagesMap())
+    whereTo->insert({s.first, &(s.second->piface_)}); // Convert each entry into its interface
 }
 
 Storage* Storage::byName(std::string name)
@@ -30,9 +31,14 @@ Storage* Storage::byName(std::string name)
   return &res->piface_;
 }
 
-const char* Storage::getName()
+const std::string& Storage::getName() const
 {
-  return pimpl_->cname();
+  return pimpl_->getName();
+}
+
+const char* Storage::getCname() const
+{
+  return pimpl_->getCname();
 }
 
 const char* Storage::getType()
@@ -45,39 +51,30 @@ Host* Storage::getHost()
   return attached_to_;
 }
 
-sg_size_t Storage::getSizeFree()
-{
-  return simgrid::simix::kernelImmediate([this] { return pimpl_->getFreeSize(); });
-}
-
-sg_size_t Storage::getSizeUsed()
-{
-  return simgrid::simix::kernelImmediate([this] { return pimpl_->getUsedSize(); });
-}
-
-sg_size_t Storage::getSize()
-{
-  return pimpl_->getSize();
-}
 
 std::map<std::string, std::string>* Storage::getProperties()
 {
   return simgrid::simix::kernelImmediate([this] { return pimpl_->getProperties(); });
 }
 
-const char* Storage::getProperty(const char* key)
+const char* Storage::getProperty(std::string key)
 {
   return this->pimpl_->getProperty(key);
 }
 
-void Storage::setProperty(const char* key, const char* value)
+void Storage::setProperty(std::string key, std::string value)
 {
   simgrid::simix::kernelImmediate([this, key, value] { this->pimpl_->setProperty(key, value); });
 }
 
-std::map<std::string, sg_size_t>* Storage::getContent()
+sg_size_t Storage::read(sg_size_t size)
 {
-  return simgrid::simix::kernelImmediate([this] { return pimpl_->getContent(); });
+  return simcall_storage_read(pimpl_, size);
+}
+
+sg_size_t Storage::write(sg_size_t size)
+{
+  return simcall_storage_write(pimpl_, size);
 }
 
 /*************
