@@ -15,18 +15,19 @@
 #include "xbt/functional.hpp"
 #include "xbt/log.h"
 #include "xbt/sysdep.h"
+#include "xbt/utility.hpp"
 
 #include "simgrid/s4u/Host.hpp"
 
 #include "mc/mc.h"
 
-#include "smx_private.h"
+#include "smx_private.hpp"
 #include "src/kernel/activity/SleepImpl.hpp"
 #include "src/kernel/activity/SynchroIo.hpp"
 #include "src/kernel/activity/SynchroRaw.hpp"
-#include "src/mc/mc_replay.h"
+#include "src/mc/mc_replay.hpp"
 #include "src/mc/remote/Client.hpp"
-#include "src/msg/msg_private.h"
+#include "src/msg/msg_private.hpp"
 #include "src/surf/cpu_interface.hpp"
 #include "src/surf/surf_interface.hpp"
 
@@ -112,9 +113,14 @@ void SIMIX_process_cleanup(smx_actor_t process)
 
   XBT_DEBUG("%p should not be run anymore",process);
   simix_global->process_list.erase(process->pid);
-  if (process->host)
-    xbt_swag_remove(process, process->host->extension<simgrid::simix::Host>()->process_list);
-  xbt_swag_insert(process, simix_global->process_to_destroy);
+  if (process->host && process->host_process_list_hook.is_linked())
+    simgrid::xbt::intrusive_erase(process->host->extension<simgrid::simix::Host>()->process_list, *process);
+  if (not process->smx_destroy_list_hook.is_linked()) {
+#if SIMGRID_HAVE_MC
+    xbt_dynar_push_as(simix_global->dead_actors_vector, smx_actor_t, process);
+#endif
+    simix_global->process_to_destroy.push_back(*process);
+  }
   process->context->iwannadie = 0;
 
   xbt_os_mutex_release(simix_global->mutex);
@@ -127,13 +133,15 @@ void SIMIX_process_cleanup(smx_actor_t process)
  */
 void SIMIX_process_empty_trash()
 {
-  smx_actor_t process = static_cast<smx_actor_t>(xbt_swag_extract(simix_global->process_to_destroy));
-
-  while (process) {
+  while (not simix_global->process_to_destroy.empty()) {
+    smx_actor_t process = &simix_global->process_to_destroy.front();
+    simix_global->process_to_destroy.pop_front();
     XBT_DEBUG("Getting rid of %p",process);
     intrusive_ptr_release(process);
-    process = static_cast<smx_actor_t>(xbt_swag_extract(simix_global->process_to_destroy));
   }
+#if SIMGRID_HAVE_MC
+  xbt_dynar_reset(simix_global->dead_actors_vector);
+#endif
 }
 
 namespace simgrid {
@@ -169,7 +177,7 @@ void ActorImpl::daemonize()
 
 simgrid::s4u::Actor* ActorImpl::restart()
 {
-  XBT_DEBUG("Restarting process %s on %s", cname(), host->getCname());
+  XBT_DEBUG("Restarting process %s on %s", getCname(), host->getCname());
 
   // retrieve the arguments of the old process
   // FIXME: Factorize this with SIMIX_host_add_auto_restart_process ?
@@ -213,7 +221,7 @@ smx_activity_t ActorImpl::suspend(ActorImpl* issuer)
 
     return nullptr;
   } else {
-    return SIMIX_execution_start(this, "suspend", 0.0, 1.0, 0.0);
+    return SIMIX_execution_start("suspend", 0.0, 1.0, 0.0, this->host);
   }
 }
 
@@ -340,18 +348,18 @@ smx_actor_t SIMIX_process_create(const char* name, std::function<void()> code, v
     host->extension_set<simgrid::simix::Host>(new simgrid::simix::Host());
 
   /* Add the process to its host process list */
-  xbt_swag_insert(process, host->extension<simgrid::simix::Host>()->process_list);
+  host->extension<simgrid::simix::Host>()->process_list.push_back(*process);
 
   XBT_DEBUG("Start context '%s'", process->name.c_str());
 
   /* Now insert it in the global process list and in the process to run list */
   simix_global->process_list[process->pid] = process;
-  XBT_DEBUG("Inserting %s(%s) in the to_run list", process->cname(), host->getCname());
+  XBT_DEBUG("Inserting %s(%s) in the to_run list", process->getCname(), host->getCname());
   simix_global->process_to_run.push_back(process);
   intrusive_ptr_add_ref(process);
 
   /* Tracing the process creation */
-  TRACE_msg_process_create(process->cname(), process->pid, process->host);
+  TRACE_msg_process_create(process->getName(), process->pid, process->host);
 
   return process;
 }
@@ -406,15 +414,15 @@ smx_actor_t SIMIX_process_attach(const char* name, void* data, const char* hostn
       process->setProperty(kv.first, kv.second);
 
   /* Add the process to it's host process list */
-  xbt_swag_insert(process, host->extension<simgrid::simix::Host>()->process_list);
+  host->extension<simgrid::simix::Host>()->process_list.push_back(*process);
 
   /* Now insert it in the global process list and in the process to run list */
   simix_global->process_list[process->pid] = process;
-  XBT_DEBUG("Inserting %s(%s) in the to_run list", process->cname(), host->getCname());
+  XBT_DEBUG("Inserting %s(%s) in the to_run list", process->getCname(), host->getCname());
   simix_global->process_to_run.push_back(process);
 
   /* Tracing the process creation */
-  TRACE_msg_process_create(process->cname(), process->pid, process->host);
+  TRACE_msg_process_create(process->getName(), process->pid, process->host);
 
   auto context = dynamic_cast<simgrid::kernel::context::AttachContext*>(process->context);
   if (not context)
@@ -464,7 +472,13 @@ void SIMIX_process_runall()
  */
 void SIMIX_process_kill(smx_actor_t process, smx_actor_t issuer) {
 
-  XBT_DEBUG("Killing process %s@%s", process->cname(), process->host->getCname());
+  if (process->finished) {
+    XBT_DEBUG("Ignoring request to kill process %s@%s that is already dead", process->getCname(),
+              process->host->getCname());
+    return;
+  }
+
+  XBT_DEBUG("Killing process %s@%s", process->getCname(), process->host->getCname());
 
   process->context->iwannadie = 1;
   process->blocked = 0;
@@ -486,7 +500,11 @@ void SIMIX_process_kill(smx_actor_t process, smx_actor_t issuer) {
         boost::dynamic_pointer_cast<simgrid::kernel::activity::IoImpl>(process->waiting_synchro);
 
     if (exec != nullptr) {
-      /* Nothing to do */
+      if (exec->surfAction_) {
+        exec->surfAction_->cancel();
+        exec->surfAction_->unref();
+        exec->surfAction_ = nullptr;
+      }
     } else if (comm != nullptr) {
       process->comms.remove(process->waiting_synchro);
       comm->cancel();
@@ -534,8 +552,8 @@ void SIMIX_process_throw(smx_actor_t process, xbt_errcat_t cat, int value, const
 
     simgrid::kernel::activity::ExecImplPtr exec =
         boost::dynamic_pointer_cast<simgrid::kernel::activity::ExecImpl>(process->waiting_synchro);
-    if (exec != nullptr && exec->surf_exec)
-      exec->surf_exec->cancel();
+    if (exec != nullptr && exec->surfAction_)
+      exec->surfAction_->cancel();
 
     simgrid::kernel::activity::CommImplPtr comm =
         boost::dynamic_pointer_cast<simgrid::kernel::activity::CommImpl>(process->waiting_synchro);
@@ -592,9 +610,9 @@ void SIMIX_process_killall(smx_actor_t issuer, int reset_pid)
 void SIMIX_process_change_host(smx_actor_t process, sg_host_t dest)
 {
   xbt_assert((process != nullptr), "Invalid parameters");
-  xbt_swag_remove(process, process->host->extension<simgrid::simix::Host>()->process_list);
+  simgrid::xbt::intrusive_erase(process->host->extension<simgrid::simix::Host>()->process_list, *process);
   process->host = dest;
-  xbt_swag_insert(process, dest->extension<simgrid::simix::Host>()->process_list);
+  dest->extension<simgrid::simix::Host>()->process_list.push_back(*process);
 }
 
 void simcall_HANDLER_process_suspend(smx_simcall_t simcall, smx_actor_t process)
@@ -718,7 +736,7 @@ void SIMIX_process_sleep_destroy(smx_activity_t synchro)
  */
 void SIMIX_process_yield(smx_actor_t self)
 {
-  XBT_DEBUG("Yield actor '%s'", self->cname());
+  XBT_DEBUG("Yield actor '%s'", self->getCname());
 
   /* Go into sleep and return control to maestro */
   self->context->suspend();
@@ -738,11 +756,11 @@ void SIMIX_process_yield(smx_actor_t self)
     SIMIX_process_on_exit_runall(self);
     /* Add the process to the list of process to restart, only if the host is down */
     if (self->auto_restart && self->host->isOff()) {
-      SIMIX_host_add_auto_restart_process(self->host, self->cname(), self->code, self->userdata,
+      SIMIX_host_add_auto_restart_process(self->host, self->getCname(), self->code, self->userdata,
                                           SIMIX_timer_get_date(self->kill_timer), self->getProperties(),
                                           self->auto_restart);
     }
-    XBT_DEBUG("Process %s@%s is dead", self->cname(), self->host->getCname());
+    XBT_DEBUG("Process %s@%s is dead", self->getCname(), self->host->getCname());
     self->context->stop();
   }
 
