@@ -1,15 +1,15 @@
-/* Copyright (c) 2007-2015. The SimGrid Team.
+/* Copyright (c) 2007-2017. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include "smx_private.h"
-#include <xbt/ex.hpp>
-#include "xbt/sysdep.h"
-#include "xbt/log.h"
-#include "xbt/xbt_os_time.h"
+#include "smx_private.hpp"
 #include "xbt/config.h"
+#include "xbt/log.h"
+#include "xbt/sysdep.h"
+#include "xbt/xbt_os_time.h"
+#include <xbt/ex.hpp>
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(simix_environment, simix, "Logging specific to SIMIX (environment)");
 
