@@ -1,15 +1,16 @@
-/* Copyright (c) 2007-2016. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2017. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "mc/mc.h"
-#include "smx_private.h"
+#include "smx_private.hpp"
 #include "src/kernel/activity/CommImpl.hpp"
-#include "src/mc/mc_replay.h"
+#include "src/mc/mc_replay.hpp"
 #include "src/plugins/vm/VirtualMachineImpl.hpp"
 #include "src/surf/surf_interface.hpp"
 #include "xbt/ex.hpp"
+#include <algorithm>
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(simix_host, simix, "SIMIX hosts");
 
@@ -21,19 +22,15 @@ namespace simgrid {
     {
       if (not Host::EXTENSION_ID.valid())
         Host::EXTENSION_ID = s4u::Host::extension_create<simix::Host>();
-
-      simgrid::simix::ActorImpl act;
-      process_list = xbt_swag_new(xbt_swag_offset(act, host_proc_hookup));
     }
 
     Host::~Host()
     {
       /* All processes should be gone when the host is turned off (by the end of the simulation). */
-      if (xbt_swag_size(process_list) != 0) {
+      if (not process_list.empty()) {
         std::string msg     = std::string("Shutting down host, but it's not empty:");
-        smx_actor_t process = nullptr;
-
-        xbt_swag_foreach(process, process_list) msg = msg + "\n\t" + process->name.c_str();
+        for (auto const& process : process_list)
+          msg += "\n\t" + std::string(process.getName());
 
         SIMIX_display_process_status();
         THROWF(arg_error, 0, "%s", msg.c_str());
@@ -44,7 +41,6 @@ namespace simgrid {
       for (auto const& arg : boot_processes)
         delete arg;
       boot_processes.clear();
-      xbt_swag_free(process_list);
     }
 
     /** Re-starts all the actors that are marked as restartable.
@@ -77,12 +73,11 @@ void SIMIX_host_off(sg_host_t h, smx_actor_t issuer)
     h->pimpl_cpu->turnOff();
 
     /* Clean Simulator data */
-    if (xbt_swag_size(host->process_list) != 0) {
-      smx_actor_t process = nullptr;
-      xbt_swag_foreach(process, host->process_list) {
-        SIMIX_process_kill(process, issuer);
-        XBT_DEBUG("Killing %s@%s on behalf of %s which turned off that host.", process->cname(),
-                  process->host->getCname(), issuer->cname());
+    if (not host->process_list.empty()) {
+      for (auto& process : host->process_list) {
+        SIMIX_process_kill(&process, issuer);
+        XBT_DEBUG("Killing %s@%s on behalf of %s which turned off that host.", process.getCname(),
+                  process.host->getCname(), issuer->getCname());
       }
     }
   } else {
@@ -150,34 +145,27 @@ void SIMIX_host_autorestart(sg_host_t host)
   process_list.clear();
 }
 
-boost::intrusive_ptr<simgrid::kernel::activity::ExecImpl> simcall_HANDLER_execution_start(smx_simcall_t simcall,
-                                                                                          const char* name,
-                                                                                          double flops_amount,
-                                                                                          double priority, double bound)
-{
-  return SIMIX_execution_start(simcall->issuer, name,flops_amount,priority,bound);
-}
-
 boost::intrusive_ptr<simgrid::kernel::activity::ExecImpl>
-SIMIX_execution_start(smx_actor_t issuer, const char* name, double flops_amount, double priority, double bound)
+SIMIX_execution_start(const char* name, double flops_amount, double priority, double bound, sg_host_t host)
 {
 
   /* alloc structures and initialize */
   simgrid::kernel::activity::ExecImplPtr exec =
-      simgrid::kernel::activity::ExecImplPtr(new simgrid::kernel::activity::ExecImpl(name, issuer->host));
+      simgrid::kernel::activity::ExecImplPtr(new simgrid::kernel::activity::ExecImpl(name, host));
 
   /* set surf's action */
   if (not MC_is_active() && not MC_record_replay_is_active()) {
 
-    exec->surf_exec = issuer->host->pimpl_cpu->execution_start(flops_amount);
-    exec->surf_exec->setData(exec.get());
-    exec->surf_exec->setSharingWeight(priority);
+    exec->surfAction_ = host->pimpl_cpu->execution_start(flops_amount);
+    exec->surfAction_->setData(exec.get());
+    exec->surfAction_->setSharingWeight(priority);
 
     if (bound > 0)
-      static_cast<simgrid::surf::CpuAction*>(exec->surf_exec)->setBound(bound);
+      static_cast<simgrid::surf::CpuAction*>(exec->surfAction_)->setBound(bound);
   }
 
   XBT_DEBUG("Create execute synchro %p: %s", exec.get(), exec->name.c_str());
+  simgrid::kernel::activity::ExecImpl::onCreation(exec);
 
   return exec;
 }
@@ -191,11 +179,6 @@ SIMIX_execution_parallel_start(const char* name, int host_nb, sg_host_t* host_li
   simgrid::kernel::activity::ExecImplPtr exec =
       simgrid::kernel::activity::ExecImplPtr(new simgrid::kernel::activity::ExecImpl(name, nullptr));
 
-  /* set surf's synchro */
-  sg_host_t *host_list_cpy = xbt_new0(sg_host_t, host_nb);
-  for (int i = 0; i < host_nb; i++)
-    host_list_cpy[i] = host_list[i];
-
   /* Check that we are not mixing VMs and PMs in the parallel task */
   bool is_a_vm = (nullptr != dynamic_cast<simgrid::s4u::VirtualMachine*>(host_list[0]));
   for (int i = 1; i < host_nb; i++) {
@@ -205,8 +188,11 @@ SIMIX_execution_parallel_start(const char* name, int host_nb, sg_host_t* host_li
 
   /* set surf's synchro */
   if (not MC_is_active() && not MC_record_replay_is_active()) {
-    exec->surf_exec = surf_host_model->executeParallelTask(host_nb, host_list_cpy, flops_amount, bytes_amount, rate);
-    exec->surf_exec->setData(exec.get());
+    /* set surf's synchro */
+    sg_host_t* host_list_cpy = new sg_host_t[host_nb];
+    std::copy_n(host_list, host_nb, host_list_cpy);
+    exec->surfAction_ = surf_host_model->executeParallelTask(host_nb, host_list_cpy, flops_amount, bytes_amount, rate);
+    exec->surfAction_->setData(exec.get());
     if (timeout > 0) {
       exec->timeoutDetector = host_list[0]->pimpl_cpu->sleep(timeout);
       exec->timeoutDetector->setData(exec.get());
@@ -219,8 +205,6 @@ SIMIX_execution_parallel_start(const char* name, int host_nb, sg_host_t* host_li
 
 void simcall_HANDLER_execution_wait(smx_simcall_t simcall, smx_activity_t synchro)
 {
-  simgrid::kernel::activity::ExecImplPtr exec =
-      boost::static_pointer_cast<simgrid::kernel::activity::ExecImpl>(synchro);
   XBT_DEBUG("Wait for execution of synchro %p, state %d", synchro.get(), (int)synchro->state);
 
   /* Associate this simcall to the synchro */
@@ -230,18 +214,37 @@ void simcall_HANDLER_execution_wait(smx_simcall_t simcall, smx_activity_t synchr
   /* set surf's synchro */
   if (MC_is_active() || MC_record_replay_is_active()) {
     synchro->state = SIMIX_DONE;
-    SIMIX_execution_finish(exec);
+    SIMIX_execution_finish(synchro);
     return;
   }
 
   /* If the synchro is already finished then perform the error handling */
   if (synchro->state != SIMIX_RUNNING)
-    SIMIX_execution_finish(exec);
+    SIMIX_execution_finish(synchro);
 }
 
-void SIMIX_execution_finish(simgrid::kernel::activity::ExecImplPtr exec)
+void simcall_HANDLER_execution_test(smx_simcall_t simcall, smx_activity_t synchro)
 {
-  for (smx_simcall_t const& simcall : exec->simcalls) {
+  simcall_execution_test__set__result(simcall, (synchro->state != SIMIX_WAITING && synchro->state != SIMIX_RUNNING));
+  if (simcall_execution_test__get__result(simcall)) {
+    synchro->simcalls.push_back(simcall);
+    SIMIX_execution_finish(synchro);
+  } else {
+    SIMIX_simcall_answer(simcall);
+  }
+  /* If the synchro is already finished then perform the error handling */
+  if (synchro->state != SIMIX_RUNNING)
+    SIMIX_execution_finish(synchro);
+}
+
+void SIMIX_execution_finish(smx_activity_t synchro)
+{
+  simgrid::kernel::activity::ExecImplPtr exec =
+      boost::static_pointer_cast<simgrid::kernel::activity::ExecImpl>(synchro);
+
+  while (not synchro->simcalls.empty()) {
+    smx_simcall_t simcall = synchro->simcalls.front();
+    synchro->simcalls.pop_front();
     switch (exec->state) {
 
       case SIMIX_DONE:
@@ -287,13 +290,13 @@ void SIMIX_set_category(smx_activity_t synchro, const char *category)
   simgrid::kernel::activity::ExecImplPtr exec =
       boost::dynamic_pointer_cast<simgrid::kernel::activity::ExecImpl>(synchro);
   if (exec != nullptr) {
-    exec->surf_exec->setCategory(category);
+    exec->surfAction_->setCategory(category);
     return;
   }
 
   simgrid::kernel::activity::CommImplPtr comm =
       boost::dynamic_pointer_cast<simgrid::kernel::activity::CommImpl>(synchro);
   if (comm != nullptr) {
-    comm->surf_comm->setCategory(category);
+    comm->surfAction_->setCategory(category);
   }
 }
